"""Tests for body measurement formatting utilities."""

from datetime import UTC, datetime, timedelta
from decimal import Decimal

import pytest
from rich.console import Console
from rich.panel import Panel
from rich.table import Table

from lift.core.models import BodyMeasurement, MeasurementUnit, WeightUnit
from lift.utils.body_formatters import (
    format_measurement_chart,
    format_measurement_detail,
    format_measurement_table,
    format_progress_comparison,
    format_progress_summary,
    format_weight_log_response,
)


@pytest.mark.formatter
class TestFormatMeasurementTable:
    """Test measurement table formatting."""

    def test_measurement_table_basic(self) -> None:
        """Test basic measurement table formatting."""
        measurements = [
            BodyMeasurement(
                id=1,
                date=datetime(2024, 1, 15, tzinfo=UTC),
                weight=Decimal("185.5"),
                weight_unit=WeightUnit.LBS,
                body_fat_pct=Decimal("15.2"),
                chest=Decimal("42.0"),
                waist=Decimal("32.0"),
                bicep_left=Decimal("15.5"),
                thigh_left=Decimal("24.0"),
                measurement_unit=MeasurementUnit.INCHES,
            ),
            BodyMeasurement(
                id=2,
                date=datetime(2024, 1, 22, tzinfo=UTC),
                weight=Decimal("187.0"),
                weight_unit=WeightUnit.LBS,
                body_fat_pct=Decimal("15.0"),
                chest=Decimal("42.5"),
                waist=Decimal("31.5"),
                bicep_left=Decimal("15.75"),
                thigh_left=Decimal("24.5"),
                measurement_unit=MeasurementUnit.INCHES,
            ),
        ]

        result = format_measurement_table(measurements)

        assert isinstance(result, Table)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "185.5" in output
        assert "187.0" in output
        assert "15.2%" in output
        assert "42.0" in output

    def test_measurement_table_empty(self) -> None:
        """Test empty measurement table."""
        result = format_measurement_table([])

        assert isinstance(result, Table)

    def test_measurement_table_partial_data(self) -> None:
        """Test measurement table with partial data."""
        measurements = [
            BodyMeasurement(
                id=1,
                date=datetime.now(),
                weight=Decimal("180.0"),
                weight_unit=WeightUnit.LBS,
                body_fat_pct=None,
                chest=None,
                waist=None,
                bicep_left=None,
                thigh_left=None,
                measurement_unit=MeasurementUnit.INCHES,
            ),
        ]

        result = format_measurement_table(measurements)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "180.0" in output
        assert "-" in output  # Should show dash for missing values

    def test_measurement_table_kilograms(self) -> None:
        """Test measurement table with kilograms."""
        measurements = [
            BodyMeasurement(
                id=1,
                date=datetime.now(),
                weight=Decimal("84.0"),
                weight_unit=WeightUnit.KG,
                measurement_unit=MeasurementUnit.CENTIMETERS,
            ),
        ]

        result = format_measurement_table(measurements)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "84" in output  # May show as 84.0 or 84
        # Weight unit shown in table


@pytest.mark.formatter
class TestFormatMeasurementDetail:
    """Test measurement detail formatting."""

    def test_measurement_detail_complete(self) -> None:
        """Test measurement detail with all fields."""
        measurement = BodyMeasurement(
            id=1,
            date=datetime(2024, 1, 15, 10, 30, tzinfo=UTC),
            weight=Decimal("185.5"),
            weight_unit=WeightUnit.LBS,
            body_fat_pct=Decimal("15.2"),
            neck=Decimal("16.0"),
            shoulders=Decimal("48.0"),
            chest=Decimal("42.0"),
            waist=Decimal("32.0"),
            hips=Decimal("38.0"),
            bicep_left=Decimal("15.5"),
            bicep_right=Decimal("15.75"),
            forearm_left=Decimal("12.5"),
            forearm_right=Decimal("12.5"),
            thigh_left=Decimal("24.0"),
            thigh_right=Decimal("24.5"),
            calf_left=Decimal("15.0"),
            calf_right=Decimal("15.0"),
            measurement_unit=MeasurementUnit.INCHES,
            notes="Feeling great!",
        )

        result = format_measurement_detail(measurement)

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "185.5" in output
        assert "15.2%" in output
        assert "16.0" in output  # neck
        assert "48.0" in output  # shoulders
        assert "42.0" in output  # chest
        assert "32.0" in output  # waist
        assert "15.5" in output  # bicep
        assert "24.0" in output  # thigh
        assert "Feeling great!" in output

    def test_measurement_detail_weight_only(self) -> None:
        """Test measurement detail with only weight."""
        measurement = BodyMeasurement(
            id=1,
            date=datetime.now(),
            weight=Decimal("180.0"),
            weight_unit=WeightUnit.LBS,
            measurement_unit=MeasurementUnit.INCHES,
        )

        result = format_measurement_detail(measurement)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "180.0" in output

    def test_measurement_detail_no_notes(self) -> None:
        """Test measurement detail without notes."""
        measurement = BodyMeasurement(
            id=1,
            date=datetime.now(),
            weight=Decimal("185.0"),
            weight_unit=WeightUnit.LBS,
            measurement_unit=MeasurementUnit.INCHES,
            notes=None,
        )

        result = format_measurement_detail(measurement)
        assert isinstance(result, Panel)


@pytest.mark.formatter
class TestFormatProgressComparison:
    """Test progress comparison formatting."""

    def test_progress_comparison_weight_gain(self) -> None:
        """Test progress comparison with weight gain."""
        current = {"weight": Decimal("187.0")}
        previous = {"weight": Decimal("185.0")}
        differences = {
            "weight": {
                "current": Decimal("187.0"),
                "previous": Decimal("185.0"),
                "change": Decimal("2.0"),
                "percent": Decimal("1.08"),
            }
        }

        result = format_progress_comparison(current, previous, differences)

        assert isinstance(result, Table)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "187.00" in output
        assert "185.00" in output
        assert "+2.00" in output

    def test_progress_comparison_weight_loss(self) -> None:
        """Test progress comparison with weight loss."""
        current = {"weight": Decimal("180.0")}
        previous = {"weight": Decimal("185.0")}
        differences = {
            "weight": {
                "current": Decimal("180.0"),
                "previous": Decimal("185.0"),
                "change": Decimal("-5.0"),
                "percent": Decimal("-2.7"),
            }
        }

        result = format_progress_comparison(current, previous, differences)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "180.00" in output
        assert "185.00" in output
        assert "-5.00" in output

    def test_progress_comparison_multiple_measurements(self) -> None:
        """Test progress comparison with multiple measurements."""
        current = {
            "weight": Decimal("187.0"),
            "body_fat_pct": Decimal("14.5"),
            "chest": Decimal("42.5"),
        }
        previous = {
            "weight": Decimal("185.0"),
            "body_fat_pct": Decimal("15.0"),
            "chest": Decimal("42.0"),
        }
        differences = {
            "weight": {
                "current": Decimal("187.0"),
                "previous": Decimal("185.0"),
                "change": Decimal("2.0"),
                "percent": Decimal("1.08"),
            },
            "body_fat_pct": {
                "current": Decimal("14.5"),
                "previous": Decimal("15.0"),
                "change": Decimal("-0.5"),
                "percent": Decimal("-3.33"),
            },
            "chest": {
                "current": Decimal("42.5"),
                "previous": Decimal("42.0"),
                "change": Decimal("0.5"),
                "percent": Decimal("1.19"),
            },
        }

        result = format_progress_comparison(current, previous, differences)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Weight" in output
        assert "Body Fat" in output
        assert "Chest" in output

    def test_progress_comparison_no_change(self) -> None:
        """Test progress comparison with no change."""
        current = {"weight": Decimal("185.0")}
        previous = {"weight": Decimal("185.0")}
        differences = {
            "weight": {
                "current": Decimal("185.0"),
                "previous": Decimal("185.0"),
                "change": Decimal("0.0"),
                "percent": Decimal("0.0"),
            }
        }

        result = format_progress_comparison(current, previous, differences)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "0.00" in output


@pytest.mark.formatter
class TestFormatMeasurementChart:
    """Test measurement chart formatting."""

    def test_measurement_chart_basic(self) -> None:
        """Test basic measurement chart."""
        data = [
            {"date": datetime(2024, 1, 1, tzinfo=UTC), "value": Decimal("180.0"), "unit": "lbs"},
            {"date": datetime(2024, 1, 8, tzinfo=UTC), "value": Decimal("182.0"), "unit": "lbs"},
            {"date": datetime(2024, 1, 15, tzinfo=UTC), "value": Decimal("185.0"), "unit": "lbs"},
        ]

        result = format_measurement_chart("Weight", data)

        assert isinstance(result, str)
        assert "Weight Trend" in result or "Weight" in result
        assert "lbs" in result

    def test_measurement_chart_empty(self) -> None:
        """Test measurement chart with no data."""
        result = format_measurement_chart("Weight", [])

        assert isinstance(result, str)
        assert "No data available" in result

    def test_measurement_chart_many_points(self) -> None:
        """Test measurement chart with many data points."""
        data = [
            {
                "date": datetime(2024, 1, 1, tzinfo=UTC) + timedelta(days=i),
                "value": Decimal(str(180.0 + i * 0.5)),
                "unit": "lbs",
            }
            for i in range(30)
        ]

        result = format_measurement_chart("Weight", data)

        assert isinstance(result, str)
        assert "lbs" in result

    def test_measurement_chart_downward_trend(self) -> None:
        """Test measurement chart with downward trend."""
        data = [
            {"date": datetime(2024, 1, 1, tzinfo=UTC), "value": Decimal("200.0"), "unit": "lbs"},
            {"date": datetime(2024, 1, 15, tzinfo=UTC), "value": Decimal("195.0"), "unit": "lbs"},
            {"date": datetime(2024, 1, 30, tzinfo=UTC), "value": Decimal("190.0"), "unit": "lbs"},
        ]

        result = format_measurement_chart("Weight", data)

        assert isinstance(result, str)
        # Should show negative trend
        assert "-" in result or "Trend" in result

    def test_measurement_chart_single_point(self) -> None:
        """Test measurement chart with single data point."""
        data = [{"date": datetime.now(), "value": Decimal("185.0"), "unit": "lbs"}]

        result = format_measurement_chart("Weight", data)

        assert isinstance(result, str)
        assert "185" in result


@pytest.mark.formatter
class TestFormatWeightLogResponse:
    """Test weight log response formatting."""

    def test_weight_log_basic(self) -> None:
        """Test basic weight log response."""
        result = format_weight_log_response(Decimal("185.5"), "lbs")

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "185.5" in output
        assert "lbs" in output

    def test_weight_log_with_previous_higher(self) -> None:
        """Test weight log with previous weight (weight gain)."""
        result = format_weight_log_response(
            Decimal("187.0"), "lbs", previous_weight=(Decimal("185.0"), "lbs")
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "187.0" in output
        assert "185.0" in output
        assert "+2.0" in output

    def test_weight_log_with_previous_lower(self) -> None:
        """Test weight log with previous weight (weight loss)."""
        result = format_weight_log_response(
            Decimal("180.0"), "lbs", previous_weight=(Decimal("185.0"), "lbs")
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "180.0" in output
        assert "185.0" in output
        assert "-5.0" in output

    def test_weight_log_with_previous_same(self) -> None:
        """Test weight log with same previous weight."""
        result = format_weight_log_response(
            Decimal("185.0"), "lbs", previous_weight=(Decimal("185.0"), "lbs")
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "no change" in output

    def test_weight_log_with_seven_day_avg(self) -> None:
        """Test weight log with 7-day average."""
        result = format_weight_log_response(Decimal("185.5"), "lbs", seven_day_avg=Decimal("184.3"))

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "184.3" in output
        assert "7-day avg" in output

    def test_weight_log_all_data(self) -> None:
        """Test weight log with all optional data."""
        result = format_weight_log_response(
            Decimal("187.0"),
            "lbs",
            previous_weight=(Decimal("185.0"), "lbs"),
            seven_day_avg=Decimal("185.5"),
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "187.0" in output
        assert "185.0" in output
        assert "185.5" in output
        assert "+2.0" in output


@pytest.mark.formatter
class TestFormatProgressSummary:
    """Test progress summary text generation."""

    def test_progress_summary_lean_mass_gain(self) -> None:
        """Test summary for lean mass gain (weight up, bf down)."""
        differences = {
            "weight": {"change": Decimal("3.0")},
            "body_fat_pct": {"change": Decimal("-0.5")},
        }

        result = format_progress_summary(4.0, differences)

        assert "Gaining lean mass" in result
        assert "Weight up" in result or "weight up" in result
        assert "body fat down" in result

    def test_progress_summary_muscle_loss(self) -> None:
        """Test summary for muscle loss (weight down, bf up)."""
        differences = {
            "weight": {"change": Decimal("-5.0")},
            "body_fat_pct": {"change": Decimal("1.0")},
        }

        result = format_progress_summary(4.0, differences)

        assert "Losing muscle mass" in result

    def test_progress_summary_dirty_bulk(self) -> None:
        """Test summary for weight gain with fat (weight up, bf up)."""
        differences = {
            "weight": {"change": Decimal("5.0")},
            "body_fat_pct": {"change": Decimal("1.5")},
        }

        result = format_progress_summary(4.0, differences)

        assert "Gaining weight with some fat" in result

    def test_progress_summary_successful_cut(self) -> None:
        """Test summary for successful cut (weight down, bf down)."""
        differences = {
            "weight": {"change": Decimal("-5.0")},
            "body_fat_pct": {"change": Decimal("-1.5")},
        }

        result = format_progress_summary(4.0, differences)

        assert "Cutting successfully" in result

    def test_progress_summary_weight_gain_only(self) -> None:
        """Test summary for weight gain without bf data."""
        differences = {"weight": {"change": Decimal("3.0")}}

        result = format_progress_summary(4.0, differences)

        assert "gaining" in result.lower()

    def test_progress_summary_weight_loss_only(self) -> None:
        """Test summary for weight loss without bf data."""
        differences = {"weight": {"change": Decimal("-3.0")}}

        result = format_progress_summary(4.0, differences)

        assert "loss" in result.lower()

    def test_progress_summary_bf_decrease_only(self) -> None:
        """Test summary for body fat decrease without weight data."""
        differences = {"body_fat_pct": {"change": Decimal("-1.0")}}

        result = format_progress_summary(4.0, differences)

        assert "recomposition" in result or "Losing fat" in result

    def test_progress_summary_bf_increase_only(self) -> None:
        """Test summary for body fat increase without weight data."""
        differences = {"body_fat_pct": {"change": Decimal("1.0")}}

        result = format_progress_summary(4.0, differences)

        assert "Body fat increasing" in result

    def test_progress_summary_no_weight_or_bf(self) -> None:
        """Test summary with no weight or body fat changes."""
        differences = {"chest": {"change": Decimal("0.5")}}

        result = format_progress_summary(4.0, differences)

        assert "4.0 weeks" in result

    def test_progress_summary_no_data(self) -> None:
        """Test summary with no data."""
        result = format_progress_summary(4.0, {})

        assert "4.0 weeks" in result



"""Tests for workout CLI commands."""

from pathlib import Path

import pytest
from typer.testing import CliRunner

from lift.main import app


runner = CliRunner()


@pytest.fixture
def temp_db(tmp_path: Path) -> str:
    """Create a temporary database path."""
    db_path = tmp_path / "test.duckdb"
    return str(db_path)


@pytest.fixture
def initialized_db(temp_db: str) -> str:
    """Create and initialize a temporary database."""
    result = runner.invoke(app, ["--db-path", temp_db, "init"])
    assert result.exit_code == 0
    return temp_db


@pytest.mark.cli
class TestWorkoutListCommands:
    """Test workout list and history commands."""

    def test_workout_incomplete_empty(self, initialized_db: str) -> None:
        """Test listing incomplete workouts when none exist."""
        result = runner.invoke(app, ["--db-path", initialized_db, "workout", "incomplete"])

        assert result.exit_code == 0
        assert "No incomplete workouts" in result.stdout

    def test_workout_history_empty(self, initialized_db: str) -> None:
        """Test workout history when no workouts exist."""
        result = runner.invoke(app, ["--db-path", initialized_db, "workout", "history"])

        assert result.exit_code == 0
        # Should succeed even with no workouts

    def test_workout_last_empty(self, initialized_db: str) -> None:
        """Test getting last workout when none exists."""
        result = runner.invoke(app, ["--db-path", initialized_db, "workout", "last"])

        assert result.exit_code == 0
        assert "No workouts found" in result.stdout or "No recent workout" in result.stdout


@pytest.mark.cli
class TestWorkoutLog:
    """Test basic workout logging."""

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_workout_log_quick_success(self, initialized_db: str) -> None:
        """Test quick workout logging with exercise ID."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestWorkoutCompletion:
    """Test workout completion and abandonment."""

    def test_complete_nonexistent_workout(self, initialized_db: str) -> None:
        """Test completing a workout that doesn't exist."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "workout", "complete", "--id", "99999"]
        )

        # Should fail gracefully
        assert result.exit_code != 0 or "not found" in result.stdout.lower()

    def test_abandon_nonexistent_workout(self, initialized_db: str) -> None:
        """Test abandoning a workout that doesn't exist."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "workout", "abandon", "--id", "99999"]
        )

        # Should fail gracefully
        assert result.exit_code != 0 or "not found" in result.stdout.lower()


@pytest.mark.cli
class TestWorkoutDelete:
    """Test workout deletion."""

    def test_delete_nonexistent_workout(self, initialized_db: str) -> None:
        """Test deleting a workout that doesn't exist."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "workout", "delete", "99999"], input="y\n"
        )

        # Should handle gracefully
        assert result.exit_code != 0 or "not found" in result.stdout.lower()

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_delete_workout_cancel(self, initialized_db: str) -> None:
        """Test canceling workout deletion."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestWorkoutDisplay:
    """Test workout display commands."""

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_workout_last_with_data(self, initialized_db: str) -> None:
        """Test displaying last workout when data exists."""
        # TODO: Rewrite to use only CLI commands for data setup

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_workout_history_with_limit(self, initialized_db: str) -> None:
        """Test workout history with limit parameter."""
        # TODO: Rewrite to use only CLI commands for data setup

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_workout_incomplete_with_data(self, initialized_db: str) -> None:
        """Test listing incomplete workouts when they exist."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestWorkoutResume:
    """Test workout resume functionality."""

    @pytest.mark.skip(reason="Resume command implementation needs verification")
    def test_resume_no_incomplete(self, initialized_db: str) -> None:
        """Test resuming when no incomplete workouts exist."""
        result = runner.invoke(app, ["--db-path", initialized_db, "workout", "resume"])

        assert result.exit_code == 0
        assert "No incomplete workouts" in result.stdout

    def test_resume_with_id_not_found(self, initialized_db: str) -> None:
        """Test resuming with invalid workout ID."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "workout", "resume", "--id", "99999"]
        )

        # Should handle gracefully
        assert result.exit_code != 0 or "not found" in result.stdout.lower()



"""Tests for workout formatting utilities."""

from datetime import UTC, datetime, timedelta
from decimal import Decimal

import pytest
from rich.console import Console
from rich.panel import Panel
from rich.table import Table
from rich.text import Text

from lift.core.models import Set, SetType, WeightUnit, Workout, WorkoutSummary
from lift.utils.workout_formatters import (
    format_exercise_performance,
    format_program_prescription,
    format_program_workout_header,
    format_progress_indicator,
    format_set_completion,
    format_set_table,
    format_workout_complete,
    format_workout_header,
    format_workout_list,
    format_workout_summary,
)


@pytest.mark.formatter
class TestFormatWorkoutSummary:
    """Test workout summary formatting."""

    def test_basic_workout_summary(self) -> None:
        """Test formatting a basic workout summary."""
        workout = Workout(
            id=1,
            name="Push Day",
            date=datetime(2024, 1, 15, 10, 30, tzinfo=UTC),
            duration_minutes=60,
            bodyweight=Decimal("180.5"),
            bodyweight_unit=WeightUnit.LBS,
        )

        summary = WorkoutSummary(
            total_exercises=5,
            total_sets=15,
            total_volume=Decimal("5000"),
            avg_rpe=Decimal("8.5"),
        )

        result = format_workout_summary(workout, summary)

        assert isinstance(result, Panel)
        # Render to string to check content
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Push Day" in output
        assert "January 15, 2024" in output
        assert "60 minutes" in output
        assert "180.5" in output
        assert "5" in output  # total exercises
        assert "15" in output  # total sets

    def test_workout_summary_with_rating(self) -> None:
        """Test workout summary with rating."""
        workout = Workout(
            id=1,
            name="Test Workout",
            date=datetime.now(),
            rating=4,
        )

        summary = WorkoutSummary(
            total_exercises=3,
            total_sets=10,
            total_volume=Decimal("1000"),
        )

        result = format_workout_summary(workout, summary)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        # Should contain star rating
        assert "★" in output

    def test_workout_summary_with_notes(self) -> None:
        """Test workout summary with notes."""
        workout = Workout(
            id=1,
            name="Test",
            date=datetime.now(),
            notes="Felt strong today!",
        )

        summary = WorkoutSummary(
            total_exercises=1,
            total_sets=3,
            total_volume=Decimal("500"),
        )

        result = format_workout_summary(workout, summary)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Felt strong today!" in output

    def test_workout_summary_minimal(self) -> None:
        """Test workout summary with minimal data."""
        workout = Workout(
            id=1,
            name=None,  # No name
            date=datetime.now(),
        )

        summary = WorkoutSummary(
            total_exercises=0,
            total_sets=0,
            total_volume=Decimal("0"),
        )

        result = format_workout_summary(workout, summary)
        assert isinstance(result, Panel)


@pytest.mark.formatter
class TestFormatSetTable:
    """Test set table formatting."""

    def test_set_table_with_exercise_names(self) -> None:
        """Test set table with exercise names shown."""
        sets = [
            Set(
                id=1,
                workout_id=1,
                exercise_id=10,
                set_number=1,
                weight=Decimal("185"),
                weight_unit=WeightUnit.LBS,
                reps=10,
                rpe=Decimal("8.0"),
                set_type=SetType.WORKING,
                completed_at=datetime.now(),
            ),
            Set(
                id=2,
                workout_id=1,
                exercise_id=10,
                set_number=2,
                weight=Decimal("185"),
                weight_unit=WeightUnit.LBS,
                reps=10,
                rpe=Decimal("8.5"),
                set_type=SetType.WORKING,
                completed_at=datetime.now(),
            ),
        ]

        result = format_set_table(sets, show_exercise_name=True)

        assert isinstance(result, Table)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Exercise 10" in output
        assert "185" in output
        assert "10" in output

    def test_set_table_without_exercise_names(self) -> None:
        """Test set table without exercise names."""
        sets = [
            Set(
                id=1,
                workout_id=1,
                exercise_id=10,
                set_number=1,
                weight=Decimal("225"),
                weight_unit=WeightUnit.LBS,
                reps=5,
                set_type=SetType.WORKING,
                completed_at=datetime.now(),
            ),
        ]

        result = format_set_table(sets, show_exercise_name=False)

        assert isinstance(result, Table)

    def test_set_table_with_no_rpe(self) -> None:
        """Test set table when RPE is not provided."""
        sets = [
            Set(
                id=1,
                workout_id=1,
                exercise_id=10,
                set_number=1,
                weight=Decimal("100"),
                weight_unit=WeightUnit.LBS,
                reps=12,
                rpe=None,
                set_type=SetType.WARMUP,
                completed_at=datetime.now(),
            ),
        ]

        result = format_set_table(sets)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "-" in output  # Should show dash for missing RPE

    def test_set_table_multiple_exercises(self) -> None:
        """Test set table with multiple different exercises."""
        sets = [
            Set(
                id=1,
                workout_id=1,
                exercise_id=10,
                set_number=1,
                weight=Decimal("185"),
                weight_unit=WeightUnit.LBS,
                reps=10,
                set_type=SetType.WORKING,
                completed_at=datetime.now(),
            ),
            Set(
                id=2,
                workout_id=1,
                exercise_id=20,
                set_number=1,
                weight=Decimal("225"),
                weight_unit=WeightUnit.LBS,
                reps=5,
                set_type=SetType.WORKING,
                completed_at=datetime.now(),
            ),
        ]

        result = format_set_table(sets, show_exercise_name=True)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Exercise 10" in output
        assert "Exercise 20" in output

    def test_set_table_empty(self) -> None:
        """Test set table with no sets."""
        result = format_set_table([])
        assert isinstance(result, Table)


@pytest.mark.formatter
class TestFormatExercisePerformance:
    """Test exercise performance formatting."""

    def test_exercise_performance_with_data(self) -> None:
        """Test formatting exercise performance with sets."""
        sets = [
            {
                "weight": Decimal("185"),
                "reps": 10,
                "rpe": Decimal("8.0"),
                "weight_unit": "lbs",
            },
            {
                "weight": Decimal("185"),
                "reps": 9,
                "rpe": Decimal("8.5"),
                "weight_unit": "lbs",
            },
        ]

        result = format_exercise_performance(
            "Bench Press", sets, last_workout_date=datetime.now() - timedelta(days=3)
        )

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Bench Press" in output
        assert "3 days ago" in output
        assert "185" in output

    def test_exercise_performance_today(self) -> None:
        """Test exercise performance when last workout was today."""
        sets = [{"weight": Decimal("100"), "reps": 10, "weight_unit": "lbs"}]

        result = format_exercise_performance("Curls", sets, last_workout_date=datetime.now())

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "earlier today" in output

    def test_exercise_performance_yesterday(self) -> None:
        """Test exercise performance when last workout was yesterday."""
        sets = [{"weight": Decimal("100"), "reps": 10, "weight_unit": "lbs"}]

        result = format_exercise_performance(
            "Squats", sets, last_workout_date=datetime.now() - timedelta(days=1)
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "yesterday" in output

    def test_exercise_performance_no_data(self) -> None:
        """Test exercise performance with no previous data."""
        result = format_exercise_performance("Deadlift", [], last_workout_date=None)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "No previous performance data" in output

    def test_exercise_performance_more_than_five_sets(self) -> None:
        """Test that only first 5 sets are shown."""
        sets = [{"weight": Decimal("100"), "reps": 10, "weight_unit": "lbs"} for _ in range(10)]

        result = format_exercise_performance("Test Exercise", sets)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        # Should show Set 1-5 but not Set 6
        assert "Set 5" in output
        assert "Set 6" not in output


@pytest.mark.formatter
class TestFormatWorkoutHeader:
    """Test workout header formatting."""

    def test_workout_header_basic(self) -> None:
        """Test basic workout header."""
        result = format_workout_header(
            "Push Day", datetime(2024, 1, 15, 14, 30, tzinfo=UTC), bodyweight=None
        )

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Push Day" in output
        assert "02:30 PM" in output

    def test_workout_header_with_bodyweight(self) -> None:
        """Test workout header with bodyweight."""
        result = format_workout_header("Pull Day", datetime.now(), bodyweight=Decimal("182.5"))

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Pull Day" in output
        assert "182.5" in output


@pytest.mark.formatter
class TestFormatSetCompletion:
    """Test set completion message formatting."""

    def test_set_completion_basic(self) -> None:
        """Test basic set completion."""
        result = format_set_completion(
            weight=Decimal("185"), reps=10, rpe=None, volume=None, is_pr=False
        )

        assert isinstance(result, Text)
        output = str(result)
        assert "185" in output
        assert "10" in output

    def test_set_completion_with_pr(self) -> None:
        """Test set completion with PR flag."""
        result = format_set_completion(weight=Decimal("225"), reps=5, is_pr=True)

        output = str(result)
        assert "PR" in output or "🏆" in output
        assert "225" in output

    def test_set_completion_with_rpe(self) -> None:
        """Test set completion with RPE."""
        result = format_set_completion(weight=Decimal("135"), reps=12, rpe=Decimal("7.5"))

        output = str(result)
        assert "7.5" in output

    def test_set_completion_with_volume(self) -> None:
        """Test set completion with volume."""
        result = format_set_completion(weight=Decimal("185"), reps=10, volume=Decimal("1850"))

        output = str(result)
        assert "1,850" in output or "1850" in output


@pytest.mark.formatter
class TestFormatWorkoutComplete:
    """Test workout completion summary formatting."""

    def test_workout_complete_basic(self) -> None:
        """Test basic workout completion summary."""
        result = format_workout_complete(
            duration_minutes=75,
            total_volume=Decimal("5000"),
            total_sets=20,
            exercise_count=6,
        )

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "75" in output
        assert "5,000" in output or "5000" in output
        assert "20" in output
        assert "6" in output
        assert "COMPLETE" in output

    def test_workout_complete_large_volume(self) -> None:
        """Test workout completion with large volume."""
        result = format_workout_complete(
            duration_minutes=90,
            total_volume=Decimal("15000"),
            total_sets=30,
            exercise_count=8,
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "15,000" in output or "15000" in output


@pytest.mark.formatter
class TestFormatWorkoutList:
    """Test workout list formatting."""

    def test_workout_list_basic(self) -> None:
        """Test formatting a list of workouts."""
        workouts = [
            (
                Workout(
                    id=1,
                    name="Push Day",
                    date=datetime(2024, 1, 15, tzinfo=UTC),
                    duration_minutes=60,
                ),
                WorkoutSummary(
                    total_exercises=5,
                    total_sets=15,
                    total_volume=Decimal("5000"),
                ),
            ),
            (
                Workout(
                    id=2,
                    name="Pull Day",
                    date=datetime(2024, 1, 17, tzinfo=UTC),
                    duration_minutes=55,
                ),
                WorkoutSummary(
                    total_exercises=4,
                    total_sets=12,
                    total_volume=Decimal("4500"),
                ),
            ),
        ]

        result = format_workout_list(workouts)

        assert isinstance(result, Table)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Push Day" in output
        assert "Pull Day" in output
        assert "60 min" in output
        assert "55 min" in output

    def test_workout_list_no_duration(self) -> None:
        """Test workout list with no duration."""
        workouts = [
            (
                Workout(
                    id=1,
                    name="Test",
                    date=datetime.now(),
                    duration_minutes=None,
                ),
                WorkoutSummary(
                    total_exercises=1,
                    total_sets=3,
                    total_volume=Decimal("500"),
                ),
            ),
        ]

        result = format_workout_list(workouts)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "-" in output  # Should show dash for missing duration

    def test_workout_list_empty(self) -> None:
        """Test empty workout list."""
        result = format_workout_list([])
        assert isinstance(result, Table)


@pytest.mark.formatter
class TestFormatProgressIndicator:
    """Test progress indicator formatting."""

    def test_progress_indicator_basic(self) -> None:
        """Test basic progress indicator."""
        result = format_progress_indicator(5, 10, label="Sets")

        assert isinstance(result, Text)
        output = str(result)
        assert "5" in output
        assert "10" in output
        assert "50" in output  # 50%

    def test_progress_indicator_complete(self) -> None:
        """Test progress indicator at 100%."""
        result = format_progress_indicator(10, 10)

        output = str(result)
        assert "100" in output

    def test_progress_indicator_zero_total(self) -> None:
        """Test progress indicator with zero total."""
        result = format_progress_indicator(0, 0)

        output = str(result)
        assert "0" in output

    def test_progress_indicator_no_label(self) -> None:
        """Test progress indicator without label."""
        result = format_progress_indicator(3, 12)

        output = str(result)
        assert "3" in output
        assert "12" in output
        assert "25" in output  # 25%


@pytest.mark.formatter
class TestFormatProgramWorkoutHeader:
    """Test program workout header formatting."""

    def test_program_workout_header_basic(self) -> None:
        """Test basic program workout header."""
        result = format_program_workout_header(
            program_name="5/3/1",
            workout_name="Week 1 - Squat",
            workout_position=1,
            total_workouts=12,
            num_exercises=5,
            estimated_duration=None,
        )

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "5/3/1" in output
        assert "Week 1 - Squat" in output
        assert "Day 1 of 12" in output
        assert "5 exercises" in output

    def test_program_workout_header_with_duration(self) -> None:
        """Test program workout header with estimated duration."""
        result = format_program_workout_header(
            program_name="PPL",
            workout_name="Push A",
            workout_position=1,
            total_workouts=6,
            num_exercises=6,
            estimated_duration=75,
        )

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "75 min" in output


@pytest.mark.formatter
class TestFormatProgramPrescription:
    """Test program prescription formatting."""

    def test_program_prescription_basic(self) -> None:
        """Test basic program prescription."""
        program_exercise = {
            "target_sets": 4,
            "target_reps_min": 8,
            "target_reps_max": 10,
        }

        result = format_program_prescription("Bench Press", program_exercise)

        assert isinstance(result, Panel)
        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "4 sets" in output
        assert "8-10 reps" in output

    def test_program_prescription_same_rep_range(self) -> None:
        """Test program prescription with same min/max reps."""
        program_exercise = {
            "target_sets": 5,
            "target_reps_min": 5,
            "target_reps_max": 5,
        }

        result = format_program_prescription("Squat", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "5 sets" in output
        assert "5 reps" in output

    def test_program_prescription_with_rpe(self) -> None:
        """Test program prescription with RPE."""
        program_exercise = {
            "target_sets": 3,
            "target_reps_min": 10,
            "target_reps_max": 12,
            "target_rpe": Decimal("8.5"),
        }

        result = format_program_prescription("Lateral Raise", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "8.5" in output

    def test_program_prescription_with_rest(self) -> None:
        """Test program prescription with rest period."""
        program_exercise = {
            "target_sets": 4,
            "target_reps_min": 5,
            "target_reps_max": 8,
            "rest_seconds": 180,
        }

        result = format_program_prescription("Deadlift", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "3m" in output  # 180 seconds = 3 minutes

    def test_program_prescription_with_rest_minutes_and_seconds(self) -> None:
        """Test program prescription with rest in minutes and seconds."""
        program_exercise = {
            "target_sets": 3,
            "target_reps_min": 12,
            "target_reps_max": 15,
            "rest_seconds": 90,  # 1m 30s
        }

        result = format_program_prescription("Leg Press", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "1m 30s" in output or "90s" in output

    def test_program_prescription_with_tempo(self) -> None:
        """Test program prescription with tempo."""
        program_exercise = {
            "target_sets": 4,
            "target_reps_min": 8,
            "target_reps_max": 10,
            "tempo": "3-1-1-0",
        }

        result = format_program_prescription("RDL", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "3-1-1-0" in output

    def test_program_prescription_with_notes(self) -> None:
        """Test program prescription with notes."""
        program_exercise = {
            "target_sets": 3,
            "target_reps_min": 10,
            "target_reps_max": 12,
            "notes": "Focus on mind-muscle connection",
        }

        result = format_program_prescription("Cable Fly", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "Focus on mind-muscle connection" in output

    def test_program_prescription_all_fields(self) -> None:
        """Test program prescription with all fields."""
        program_exercise = {
            "target_sets": 4,
            "target_reps_min": 6,
            "target_reps_max": 8,
            "target_rpe": Decimal("9.0"),
            "rest_seconds": 240,
            "tempo": "2-0-2-0",
            "notes": "Increase weight if RPE < 8",
        }

        result = format_program_prescription("Barbell Row", program_exercise)

        console = Console()
        with console.capture() as capture:
            console.print(result)
        output = capture.get()

        assert "4 sets" in output
        assert "6-8 reps" in output
        assert "9.0" in output
        assert "4m" in output
        assert "2-0-2-0" in output
        assert "Increase weight if RPE < 8" in output



"""Tests for stats CLI commands."""

from pathlib import Path

import pytest
from typer.testing import CliRunner

from lift.main import app


runner = CliRunner()


@pytest.fixture
def temp_db(tmp_path: Path) -> str:
    """Create a temporary database path."""
    db_path = tmp_path / "test.duckdb"
    return str(db_path)


@pytest.fixture
def initialized_db(temp_db: str) -> str:
    """Create and initialize a temporary database."""
    result = runner.invoke(app, ["--db-path", temp_db, "init"])
    assert result.exit_code == 0
    return temp_db


@pytest.mark.cli
class TestStatsSummary:
    """Test stats summary commands."""

    def test_summary_empty(self, initialized_db: str) -> None:
        """Test stats summary with no data."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "summary"])

        assert result.exit_code == 0
        # Should show 0 workouts or similar

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_summary_with_data(self, initialized_db: str) -> None:
        """Test stats summary with workout data."""
        # TODO: Rewrite to use only CLI commands for data setup

    @pytest.mark.skip(reason="Period parameter not yet implemented in CLI")
    def test_summary_with_period(self, initialized_db: str) -> None:
        """Test stats summary with period parameter."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "stats", "summary", "--period", "month"]
        )

        assert result.exit_code == 0

    def test_summary_invalid_period(self, initialized_db: str) -> None:
        """Test stats summary with invalid period."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "stats", "summary", "--period", "invalid"]
        )

        # Should fail or handle gracefully
        assert result.exit_code != 0 or "invalid" in result.stdout.lower()


@pytest.mark.cli
class TestStatsExercise:
    """Test exercise statistics commands."""

    def test_exercise_stats_no_exercise(self, initialized_db: str) -> None:
        """Test exercise stats when exercise doesn't exist."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "exercise", "99999"])

        assert result.exit_code != 0 or "not found" in result.stdout.lower()

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_exercise_stats_with_data(self, initialized_db: str) -> None:
        """Test exercise stats with actual data."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestStatsVolume:
    """Test volume statistics commands."""

    def test_volume_empty(self, initialized_db: str) -> None:
        """Test volume stats with no data."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "volume"])

        assert result.exit_code == 0
        # Should handle empty case

    def test_volume_with_weeks(self, initialized_db: str) -> None:
        """Test volume stats with weeks parameter."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "stats", "volume", "--weeks", "12"]
        )

        assert result.exit_code == 0


@pytest.mark.cli
class TestStatsPR:
    """Test PR (personal record) statistics."""

    def test_pr_list_empty(self, initialized_db: str) -> None:
        """Test listing PRs when none exist."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "pr"])

        assert result.exit_code == 0
        # Should show no PRs or empty list

    def test_pr_for_exercise_not_found(self, initialized_db: str) -> None:
        """Test PRs for non-existent exercise."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "stats", "pr", "--exercise", "99999"]
        )

        # Should handle gracefully
        assert result.exit_code != 0 or "not found" in result.stdout.lower()


@pytest.mark.cli
class TestStatsMuscle:
    """Test muscle volume statistics."""

    @pytest.mark.skip(reason="Muscle stats CLI command not yet fully implemented")
    def test_muscle_volume_empty(self, initialized_db: str) -> None:
        """Test muscle volume with no data."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "muscle"])

        assert result.exit_code == 0
        # Should handle empty case

    @pytest.mark.skip(reason="Muscle stats CLI command not yet fully implemented")
    def test_muscle_volume_with_weeks(self, initialized_db: str) -> None:
        """Test muscle volume with weeks parameter."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "stats", "muscle", "--weeks", "4"]
        )

        assert result.exit_code == 0


@pytest.mark.cli
class TestStatsStreak:
    """Test consistency streak statistics."""

    def test_streak_empty(self, initialized_db: str) -> None:
        """Test streak with no workouts."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "streak"])

        assert result.exit_code == 0
        assert "No active streak" in result.stdout or "0" in result.stdout

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_streak_with_data(self, initialized_db: str) -> None:
        """Test streak with workout data."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestStatsProgress:
    """Test progress statistics."""

    def test_progress_no_exercise(self, initialized_db: str) -> None:
        """Test progress for non-existent exercise."""
        result = runner.invoke(app, ["--db-path", initialized_db, "stats", "progress", "99999"])

        assert result.exit_code != 0 or "not found" in result.stdout.lower()

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_progress_with_limit(self, initialized_db: str) -> None:
        """Test progress with limit parameter."""
        # TODO: Rewrite to use only CLI commands for data setup



"""Tests for body tracking CLI commands."""

from pathlib import Path

import pytest
from typer.testing import CliRunner

from lift.main import app


runner = CliRunner()


@pytest.fixture
def temp_db(tmp_path: Path) -> str:
    """Create a temporary database path."""
    db_path = tmp_path / "test.duckdb"
    return str(db_path)


@pytest.fixture
def initialized_db(temp_db: str) -> str:
    """Create and initialize a temporary database."""
    result = runner.invoke(app, ["--db-path", temp_db, "init"])
    assert result.exit_code == 0
    return temp_db


@pytest.mark.cli
class TestBodyWeight:
    """Test body weight logging commands."""

    def test_log_weight_lbs(self, initialized_db: str) -> None:
        """Test logging weight in pounds."""
        result = runner.invoke(app, ["--db-path", initialized_db, "body", "weight", "185.5"])

        assert result.exit_code == 0
        assert "185.5" in result.stdout or "logged" in result.stdout.lower()

    def test_log_weight_kg(self, initialized_db: str) -> None:
        """Test logging weight in kilograms."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "body", "weight", "84.0", "--unit", "kg"]
        )

        assert result.exit_code == 0
        assert "84" in result.stdout or "logged" in result.stdout.lower()

    def test_log_weight_invalid(self, initialized_db: str) -> None:
        """Test logging invalid weight value."""
        result = runner.invoke(app, ["--db-path", initialized_db, "body", "weight", "invalid"])

        assert result.exit_code != 0

    def test_log_weight_shows_previous(self, initialized_db: str) -> None:
        """Test that logging weight shows previous weight."""
        # Log first weight via CLI
        result1 = runner.invoke(app, ["--db-path", initialized_db, "body", "weight", "180.0"])
        assert result1.exit_code == 0

        # Log second weight
        result = runner.invoke(app, ["--db-path", initialized_db, "body", "weight", "182.5"])

        assert result.exit_code == 0
        # Should show comparison with previous weight


@pytest.mark.cli
class TestBodyHistory:
    """Test body measurement history commands."""

    def test_history_empty(self, initialized_db: str) -> None:
        """Test viewing history with no measurements."""
        result = runner.invoke(app, ["--db-path", initialized_db, "body", "history"])

        assert result.exit_code == 0
        # Should handle empty case gracefully

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_history_with_data(self, initialized_db: str) -> None:
        """Test viewing history with measurements."""
        # TODO: Rewrite to use only CLI commands for data setup

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_history_with_limit(self, initialized_db: str) -> None:
        """Test viewing history with limit parameter."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestBodyLatest:
    """Test latest body measurement commands."""

    def test_latest_empty(self, initialized_db: str) -> None:
        """Test getting latest measurement when none exist."""
        result = runner.invoke(app, ["--db-path", initialized_db, "body", "latest"])

        assert result.exit_code == 0
        assert "No measurements" in result.stdout or "no data" in result.stdout.lower()

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_latest_with_data(self, initialized_db: str) -> None:
        """Test getting latest measurement."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestBodyProgress:
    """Test body progress tracking commands."""

    @pytest.mark.skip(reason="Body progress CLI command not yet fully implemented")
    def test_progress_empty(self, initialized_db: str) -> None:
        """Test viewing progress with no data."""
        result = runner.invoke(app, ["--db-path", initialized_db, "body", "progress"])

        assert result.exit_code == 0
        # Should handle empty case

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_progress_with_data(self, initialized_db: str) -> None:
        """Test viewing progress with measurements."""
        # TODO: Rewrite to use only CLI commands for data setup


@pytest.mark.cli
class TestBodyCompare:
    """Test body measurement comparison commands."""

    def test_compare_invalid_ids(self, initialized_db: str) -> None:
        """Test comparing non-existent measurements."""
        result = runner.invoke(
            app, ["--db-path", initialized_db, "body", "compare", "99999", "99998"]
        )

        # Should fail or handle gracefully
        assert result.exit_code != 0 or "not found" in result.stdout.lower()

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_compare_same_id(self, initialized_db: str) -> None:
        """Test comparing a measurement with itself."""
        # TODO: Rewrite to use only CLI commands for data setup

    @pytest.mark.skip(reason="Needs proper CLI-only test implementation")
    def test_compare_two_measurements(self, initialized_db: str) -> None:
        """Test comparing two different measurements."""
        # TODO: Rewrite to use only CLI commands for data setup
